@@ -6,7 +6,7 @@
 Module to handle the creation of the root EFS stack
 """
 
-from troposphere import Ref, GetAtt, Sub, Select
+from troposphere import GetAtt, Ref, Select, Sub
 from troposphere.ec2 import SecurityGroup
 from troposphere.efs import FileSystem, MountTarget
 
@@ -14,12 +14,12 @@ from ecs_composex.common import build_template
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.efs.efs_params import (
-    RES_KEY,
-    FS_ID,
     FS_ARN,
+    FS_ID,
+    FS_MNT_PT_SG_ID,
     FS_PORT,
     MOD_KEY,
-    FS_MNT_PT_SG_ID,
+    RES_KEY,
 )
 from ecs_composex.resources_import import import_record_properties
 from ecs_composex.vpc.vpc_params import STORAGE_SUBNETS, VPC_ID
